==> ns-sso-client-2.0.0-20251203.084505-76-sources.jar: com/geoway/sso/client/client/impl/SystemClientImpl.java <==
package com.geoway.sso.client.client.impl;

import com.geoway.sso.client.client.SystemClient;
import com.geoway.sso.client.rpc.Result;
import com.geoway.sso.client.rpc.RpcSysSystemConsult;
import com.geoway.sso.client.rpc.RpcSysTenant;
import com.geoway.sso.client.rpc.RpcSystemInfoDTO;
import com.geoway.sso.client.util.UisUtils;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @author 连世忠
 * @ClassName SystemClientImpl
 * @Description TODO
 * @date 2025/7/16 8:55
 * @Version 1.0
 */
@Component
public class SystemClientImpl extends Client implements SystemClient {
    @Override
    public RpcSystemInfoDTO querySystemInfoByKey(String systemKey) {
        Result<RpcSystemInfoDTO> result = UisUtils.querySystemInfoByKey(provider.getRpcClientInfo().getServerUrl(), systemKey, getHeader());
        if (result == null) {
            return null;
        }
        if (result.isSuccess()) {
            return result.getData();
        } else {
            throw new RuntimeException(result.getMessage());
        }
    }

    @Override
    public List<RpcSysTenant> queryTenants(String systemId) {
        Result<List<RpcSysTenant>> result = UisUtils.querySystemTenants(provider.getRpcClientInfo().getServerUrl(), systemId, getHeader());
        if (result == null) {
            return null;
        }
        if (result.isSuccess()) {
            return result.getData();
        } else {
            throw new RuntimeException(result.getMessage());
        }
    }

    @Override
    public Result<Void> saveSystemConsult(RpcSysSystemConsult consult) {
        return UisUtils.saveSystemConsult(provider.getRpcClientInfo().getServerUrl(), consult, getHeader());
    }
}

==> ns-sso-client-2.0.0-20251203.085156-77-sources.jar: com/geoway/sso/client/client/impl/SystemClientImpl.java <==
package com.geoway.sso.client.client.impl;

import cn.hutool.core.util.ObjectUtil;
import com.geoway.sso.client.client.SystemClient;
import com.geoway.sso.client.rpc.Result;
import com.geoway.sso.client.rpc.RpcSysSystemConsult;
import com.geoway.sso.client.rpc.RpcSysTenant;
import com.geoway.sso.client.rpc.RpcSystemInfoDTO;
import com.geoway.sso.client.util.UisUtils;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @author 连世忠
 * @ClassName SystemClientImpl
 * @Description TODO
 * @date 2025/7/16 8:55
 * @Version 1.0
 */
@Component
public class SystemClientImpl extends Client implements SystemClient {
    @Override
    public RpcSystemInfoDTO querySystemInfoByKey(String systemKey) {
        Result<RpcSystemInfoDTO> result = UisUtils.querySystemInfoByKey(provider.getRpcClientInfo().getServerUrl(), systemKey, getHeader());
        if (result == null) {
            return null;
        }
        if (result.isSuccess()) {
            return result.getData();
        } else {
            throw new RuntimeException(result.getMessage());
        }
    }

    @Override
    public List<RpcSysTenant> queryTenants(String systemId) {
        if(ObjectUtil.isNotEmpty(systemId)){
            systemId = provider.getRpcClientInfo().getSystemId();
        }
        Result<List<RpcSysTenant>> result = UisUtils.querySystemTenants(provider.getRpcClientInfo().getServerUrl(), systemId, getHeader());
        if (result == null) {
            return null;
        }
        if (result.isSuccess()) {
            return result.getData();
        } else {
            throw new RuntimeException(result.getMessage());
        }
    }

    @Override
    public Result<Void> saveSystemConsult(RpcSysSystemConsult consult) {
        return UisUtils.saveSystemConsult(provider.getRpcClientInfo().getServerUrl(), consult, getHeader());
    }
}
